# 👷 Contributing

There are many ways you can contribute, all of them welcome! Here are some ideas of increasing difficulty:

- Check out the [documentation](https://tasts-robots.org/doc/ltv-mpc/) and report mistakes or ask questions
- Try out the [examples](examples) and report any issue
- Write your own MPC example and add it to the collection
- Suggests improvements to simplify the API
- Find a use case that is not covered and write a unit test for it
- Implement general linear stage cost functions

If you are interested in helping out, open an issue so we can track progress. If you already have a PR, open it so we can review it :)
